#
# spec file for package lame
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 0
Name:           lame
Version:        3.99.5
Release:        2.1
Summary:        The LAME MP3 encoder
License:        LGPL-2.0+
Group:          Productivity/Multimedia/Sound/Editors and Convertors
# https://github.com/rbrito/lame
Url:            http://lame.sourceforge.net/
Source:         http://prdownloads.sourceforge.net/lame/lame-%{version}.tar.gz
Source99:       lame-rpmlintrc
Source1000:     baselibs.conf
Patch1:         lame-gtk1.patch
Patch10:        lame-Add-check-for-invalid-input-sample-rate.patch
Patch11:        lame-ansi2knr2.patch
Patch12:        lame-bits_per_sample.patch
Patch13:        lame-field-width-fix.patch
Patch14:        lame-force_align_arg_pointer.patch
Patch15:        lame-int_resample_ratio.patch
Patch16:        lame-msse.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
Requires:       libmp3lame%{sover} >= %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%ifarch %ix86
BuildRequires:  nasm
%endif
BuildRequires:  pkgconfig(gtk+-2.0)

%description
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

%package doc
Summary:        Documentation for the LAME MP3 encoder
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       %{name} = %{version}

%description doc
LAME is an encoder that converts audio to the MP3 file format. It has
an improved psychoacoustic model and performs well in codec listening
tests.

%package -n libmp3lame%{sover}
Summary:        The LAME MP3 encoder library
Group:          System/Libraries

%description -n libmp3lame%{sover}
LAME is an encoder that converts audio to the MP3 file format. It has
an improved psychoacoustic model and performs well in codec listening
tests.

%package -n libmp3lame-devel
Summary:        Development files for the LAME MP3 encoder
Group:          Development/Libraries/C and C++
Requires:       libmp3lame%{sover} = %{version}

%description -n libmp3lame-devel
Contains the header files for use with LAME's encoding library.

%package -n lame-mp3rtp
Summary:        MP3 Encoder for RTP Streaming
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       libmp3lame%{sover} >= %{version}

%description -n lame-mp3rtp
LAME is an encoder that converts audio to the MP3 file format. It has
an improved psychoacoustic model and performs well in codec listening
tests.

This package includes "mp3rtp", an MP3 encoder with RTP streaming of the output.


%prep
%setup -q
find -name Makefile.in -print -delete
%patch1 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
sed -i -e '/define sp/s/+/ + /g' libmp3lame/i386/nasm.h

%build
autoreconf -fi
LIBS="-lm" \
CFLAGS="%{optflags}" \
%configure \
    --enable-nasm \
    --enable-decoder \
    --disable-debug \
    --enable-mp3rtp \
    --with-fileio=lame \
    --enable-dynamic-frontends \
    --disable-rpath \
    --disable-static

make %{?_smp_mflags} pkgdocdir=%{_defaultdocdir}/%{name}/

%install
make install pkgdocdir=%{_defaultdocdir}/%{name}/ DESTDIR=%{buildroot}
rm -f %{buildroot}%{_libdir}/libmp3lame.la

for f in ChangeLog README TODO USAGE; do
    install -m0644 "$f" "%{buildroot}%{_defaultdocdir}/%{name}/"
done

%post   -n libmp3lame%{sover} -p /sbin/ldconfig

%postun -n libmp3lame%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/lame
%{_mandir}/man1/lame.1*

%files doc
%defattr(-,root,root)
%{_defaultdocdir}/%{name}

%files -n libmp3lame%{sover}
%defattr(0644,root,root,0755)
%doc COPYING LICENSE
%{_libdir}/libmp3lame.so.%{sover}
%{_libdir}/libmp3lame.so.%{sover}.*

%files -n libmp3lame-devel
%defattr(-,root,root)
%doc API HACKING STYLEGUIDE
%{_includedir}/lame/
%{_libdir}/libmp3lame.so

%files -n lame-mp3rtp
%defattr(-,root,root)
%{_bindir}/mp3rtp

%changelog
* Thu Mar  2 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
- Replace goals with what the software really does.
* Sat Jun 20 2015 olaf@aepfle.de
- Add patch for SSE
- Add check for invalid input sample rate
- Avoid malformed wav causing floating point exception (integer divide by zero)
- Fix warning on 64 bit machines. Explicitely set variables as unsigned ints.
- Enable functions with SSE instructions to maintain their own properly aligned stack
- Fix decision if sample rate ratio is an integer value or not
- run autoreconf, set GTK_CFLAGS
- Add patch to remove ansi2knr instead of using sed
* Tue Feb  3 2015 scarabeus@opensuse.org
- Redux the conditionals for not building gtk1 anywhere anymore
* Fri Nov  1 2013 obs@botter.cc
- Fix logical issue in hvogel's fix
* Thu Oct 31 2013 hvogel@opensuse.org
- Fix the conditional building of gtk1 binaries
* Tue Oct 15 2013 obs@botter.cc
- Fix pkgconfig(gtk+-2.0) for >= 11.4
* Thu Jul 19 2012 reddwarf@opensuse.org
- Fix bug reporting link
- BuildRequires nasm only in x86-32 (there is no assembly available
  for other archs)
- Stop BuildRequiring flac-devel, it's not used
- Remove autoreconf call and related BuildRequires and patches
- Remove old compatibility Provides
- Run spec-cleaner
- Removed all patches (unneeded)
- Replace some documentation and let the build system install its
  own
* Tue Jul 17 2012 pascal.bleser@opensuse.org
- update to 3.99.5: fixed build on 12.2
* Tue Nov 22 2011 pascal.bleser@opensuse.org
- disable sndfile for IO, causes more issues than anything else (warnings and
  issues in several applications that use lame)
- lame-tgetstr.patch: fix build on openSUSE > 12.1, tput and friends are now in
  libtinfo
* Mon Mar  7 2011 pascal.bleser@opensuse.org
- add Gentoo patch that fixes reading from stdin
- add rpmlintrc
- split out documentation into subpackage
* Fri Jun 18 2010 lnussel@suse.de
- disable use of gtk in 11.3, was dropped
* Sat Mar 27 2010 pascal@links2linux.de
- update to 3.98.4:
  * fix for #2973877, a problem regarding the new drain code
* Sun Feb 28 2010 pascal@links2linux.de
- update to 3.98.3:
  * a very important interaction with the FhG decoder was fixed
  * the hip audio decoding library is used to perform a better job
    when reencoding MP3 files to MP3 files
  * bugs were worked around to improve compatibility with ffmpeg
  * many fixes were made regarding ID3 tags, including correct
    specification of the length of the tracks
- dropped cvs patch, merged upstream
* Fri Aug 21 2009 Manfred.Tremmel@iiv.de
- cleanups cvs patch
- removed static library
* Sat May 30 2009 Manfred.Tremmel@iiv.de
- patch from cvs to fix buffer problems with ffmpeg
* Tue Sep 23 2008 guru@unixtech.be
- added Authors: in description blocks
- use libsndfile for fileio, as it seems to be the prefered default now
- update to 3.98.2:
  * adds some quality improvements to the generated audio files
  * enables the user to choose fractional variable bitrate qualities
  * upgraded support for libsndfile1 (and, in turn, can use many file formats as input, including FLAC files)
  * includes many bugfixes, including peripheral tools for user convenience
* Sun Jul 13 2008 guru@unixtech.be
- added ldconfig in post and postun
- changed release to 0.pm.1 (instead of 1)
- split off shared library and -devel packages (still Requires by lame for
  backwards compatibility, may change later)
- fixed Group:
- added BuildRequires
- added debuginfo support
- revamped spec file
* Wed Dec 20 2006 henne@links2linux.de
- update to version 3.97
- build against libm for k3b
* Tue Feb 28 2006 henne@links2linux.de
- package missing include dir
* Sat Nov 27 2004 henne@links2linux.de
- make spec file lib/lib64 clean
* Sun Oct 17 2004 henne@links2linux.de
- updated to version 3.96.1
* Wed May  5 2004 henne@links2linux.de
- updated to version 3.95.1
* Sun Sep 28 2003 henne@links2linux.de
- updated to version 3.93.1
* Sun Aug 31 2003 henne@links2linux.de
- remove buildarch
* Sun Mar 23 2003 henne@links2linux.de
- compiled for 8.2
* Sun Sep 15 2002 henne@links2linux.de
- updated version to 3.92
* Mon Jan 28 2002 waldemar@links2linux.de
- new release
* Tue May 15 2001 waldemar@links2linux.de
- new beta
* Tue Jan 23 2001 waldemar@links2linux.de
- added mlame, script for multiple encoding with lame
* Thu Jan 11 2001 waldemar@links2linux.de
- compiled without ogg/vorbis support, because to buggy
* Wed Jan  3 2001 waldemar@links2linux.de
- first release
